struct XHRContext {
xhr: Trusted<XMLHttpRequest>,
gen_id: GenerationId,
sync_status: Arc<AtomicRefCell<Option<ErrorResult>>>,
url: ServoUrl,
}Expand description
Closure of required data for each async network event that comprises the XHR’s response.
Fields
xhr: Trusted<XMLHttpRequest>gen_id: GenerationIdsync_status: Arc<AtomicRefCell<Option<ErrorResult>>>url: ServoUrlTrait Implementations
Sourceimpl FetchResponseListener for XHRContext
impl FetchResponseListener for XHRContext
fn process_request_body(&mut self, _: RequestId)
fn process_response( &mut self, cx: &mut JSContext, _: RequestId, metadata: Result<FetchMetadata, NetworkError>, )
fn process_response_chunk( &mut self, cx: &mut JSContext, _: RequestId, chunk: Vec<u8>, )
fn process_response_eof( self, cx: &mut JSContext, _: RequestId, response: Result<(), NetworkError>, timing: ResourceFetchTiming, )
fn process_csp_violations( &mut self, _request_id: RequestId, violations: Vec<Violation>, )
Sourcefn should_invoke(&self) -> bool
fn should_invoke(&self) -> bool
A gating mechanism that runs before invoking the listener methods on the target
thread. If the
should_invoke method returns false, the listener does not receive
the notification.Sourceimpl ResourceTimingListener for XHRContext
impl ResourceTimingListener for XHRContext
fn resource_timing_information(&self) -> (InitiatorType, ServoUrl)
fn resource_timing_global(&self) -> DomRoot<GlobalScope>